#!/bin/sh
#
# Copyright (c) 2011-2012 EBM WebSourcing, 2012-2015 Linagora
#
# This program/library is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 2.1 of the License, or (at your
# option) any later version.
#
# This program/library is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
# for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program/library; If not, see <http://www.gnu.org/licenses/>
# for the GNU Lesser General Public License version 2.1.
#
#############################################################################
#
#                      Petals ESB Bootstrap Script
#
# Environment variables:
#
#	JAVA_HOME			Directory containing the JRE. Use the java executable
#						found in $PATH if not defined.
#
#	PETALS_JAVA_OPTS	Options for the JVM. Try "java -h" to get informations
#						about the available options for your environment
#
#############################################################################

# Extra checks
set -eu

# Let's work directly in the distribution folder to avoid space in names if there is
cd "$(dirname "$0")/../"

# Set the path to the java executable
JAVA="${JAVA_HOME:-}/bin/java"
[ -x "$JAVA" ] || JAVA="$(which java)" || {
	echo "ERROR: java executable not found" >&2
	exit 1
}

PETALS_LIB_DIR="./lib"
PETALS_EXT_DIR="./extensions"

# Retrieve the path to petals bootstrap jar
PETALS_LAUNCHER_PATTERN="petals-launcher-default-*.jar"
PETALS_LAUNCHER_ARTIFACT="$(ls -1 $PETALS_LIB_DIR/$PETALS_LAUNCHER_PATTERN 2>/dev/null)"
# Check that the JAR is defined once
if [ -z "$PETALS_LAUNCHER_ARTIFACT" ]; then
   echo "ERROR: No Petals launcher found in directory $PETALS_LIB_DIR". Pattern was: $PETALS_LAUNCHER_PATTERN >&2
   exit 1
fi
# And only once!
if [ "$(echo "$PETALS_LAUNCHER_ARTIFACT" | wc -l)" -ne 1 ]; then
   echo -e "ERROR: Several Petals launcher versions were found in $PETALS_LIB_DIR:\n$PETALS_LAUNCHER_ARTIFACT" >&2
   exit 1
fi

# Adapt pathes if architecture is Cygwin
case "`uname`" in
	CYGWIN*)
		JAVA="$(cygpath --unix $JAVA)"
		PETALS_LIB_DIR="$(cygpath --dos $PETALS_LIB_DIR)"
		PETALS_JAR="$(cygpath --unix $PETALS_LAUNCHER_ARTIFACT)"
		;;
esac

# Logs
if [ -z "${PETALS_CLASSPATH:-}" ]; then
   PETALS_LOG_PATTERN="petals-log-*.jar"
   PETALS_LOG_ARTIFACT="$(ls -1 $PETALS_LIB_DIR/$PETALS_LOG_PATTERN 2>/dev/null)"

   # Check that the JAR is defined once
   if [ -z "$PETALS_LOG_ARTIFACT" ]; then
      echo "ERROR: Petals Log Handler not found in $PETALS_LIB_DIR. Pattern was: $PETALS_LOG_PATTERN" >&2
      exit 1
   fi;
   # And only once!
   if [ "$(echo "$PETALS_LOG_ARTIFACT" | wc -l)" -ne 1 ]; then
      echo -e "ERROR: Several Petals Log Handler versions were found in $PETALS_LIB_DIR:\n$PETALS_LOG_ARTIFACT" >&2
      exit 1
   fi
   
   PETALS_CLASSPATH="$PETALS_LOG_ARTIFACT"
fi

# 

# Add the conf directory to the classpath to provide the default server configuration
PETALS_CLASSPATH="$PETALS_CLASSPATH:./conf"

# Add the launcher jar
PETALS_CLASSPATH="$PETALS_CLASSPATH:$PETALS_LAUNCHER_ARTIFACT"

if [ -z "${PETALS_JAVA_OPTS:-}" ]; then
   PETALS_JAVA_OPTS=""
fi

ENV_FILE="./conf/env.sh"
if [ -f "$ENV_FILE" ]; then
   . "$ENV_FILE"
fi

# Saxon is our XSLT engine
PETALS_XSLT_ENGINE=net.sf.saxon.TransformerFactoryImpl

# Start
exec "$JAVA" \
	-classpath "$PETALS_CLASSPATH" \
	-Dpetals.lib.dir="$PETALS_LIB_DIR" \
	-Dpetals.ext.dir="$PETALS_EXT_DIR" \
	-Djavax.xml.transform.TransformerFactory="$PETALS_XSLT_ENGINE" \
	$PETALS_JAVA_OPTS \
	org.ow2.petals.launcher.PetalsLauncher \
	"$@"
